@@ -17,7 +17,7 @@ from ..utils import async_helpers
 from ..utils.miscellaneous import stream_data
 from .. import _CAROL_METADATA_GOLDEN, _NEEDED_FOR_MERGE, _REJECTED_DM_COLS, _CAROL_METADATA_UNTIE_GOLDEN
 from ..utils.miscellaneous import drop_duplicated_parquet, drop_duplicated_parquet_dask
-from ..utils.deprecation_msgs import _deprecation_msgs
+from ..utils.deprecation_msgs import _deprecation_msgs, deprecated
 from ..exceptions import CarolApiResponseException
 
 _DATA_MODEL_TYPES_MAPPING = {
@@ -102,6 +102,7 @@ class DataModel:
             {resp['mdmName']: self._get_name_type_data_models(resp['mdmFields'])})
         return resp
 
+    @deprecated('2.55.2', '2.56.0', 'CDS Data reading is deprecated - Use Big Query layer to read data from Carol.')
     def fetch_parquet(
             self, dm_name, merge_records=True, backend='pandas',
             return_dask_graph=False,
@@ -337,53 +338,6 @@ class DataModel:
         self.snapshot_ = {resp['entityTemplateName']: resp}
         return resp
 
-    def export(self, dm_name=None, dm_id=None, sync_dm=True, full_export=False, delete_previous=False):
-        """
-
-        @DEPRECATED. This function was removed in pycarol 3.34
-
-        Export data models
-
-        This method will trigger or pause the export of the data in the datamodel to
-        CDS
-
-        :param dm_name: `str`, default `None`
-            Data model Name
-        :param dm_id: `str`, default `None`
-            Data model id
-        :param sync_dm: `bool`, default `True`
-            Sync the data model
-        :param full_export: `bool`, default `True`
-            Do a resync of the data model
-        :param delete_previous: `bool`, default `False`
-            Delete previous exported files.
-        :return: None
-        """
-        _deprecation_msgs("This function was removed from pyCarol")
-        return None
-
-    def export_all(self, sync_dm=True, full_export=False, delete_previous=False):
-        """
-
-        @DEPRECATED. This function was removed in pycarol 3.34
-
-        Export all data models
-
-        This method will trigger or pause the export of the data in the datamodel to
-        CDS
-
-        :param sync_dm: `bool`, default `True`
-            Sync the data model
-        :param full_export: `bool`, default `True`
-            Do a resync of the data model
-        :param delete_previous: `bool`, default `False`
-            Delete previous exported files.
-        :return: None
-        """
-
-        _deprecation_msgs("This function was removed from pyCarol")
-        return None
-
     def delete(self, dm_id=None, dm_name=None, entity_space='WORKING'):
         # TODO: Check Possible entity_spaces
 
@@ -407,20 +361,6 @@ class DataModel:
                     field['mdmFields'])
         return f
 
-    def _get_dm_export_stats(self):
-        """
-
-        @DEPRECATED. This function was removed in pycarol 3.34
-
-        Get export status for data models
-
-        :return: `dict`
-            dict with the information of which data model is exporting its data.
-        """
-
-        _deprecation_msgs("This function was removed from pyCarol")
-        return None
-
     def reprocess_rejected(self, dm_name=None, dm_id=None, delete_records=True):
         """
         Reprocess rejected records.
@@ -574,56 +514,6 @@ class DataModel:
                 if print_stats:
                     print('{}/{} sent'.format(cont, data_size), end='\r')
 
-    def create_mapping(self, staging_name, connector_id=None, connector_name=None, dm_name=None, dm_id=None,
-                       publish=False):
-        """
-
-        This method will create the link between the staging and a data model. If Publish=True it will publish how it is.
-
-        :param staging_name:  `str`
-            Name of the staging to be mapped.
-        :param connector_id:  `str`, `str`, default `None`
-            Staging's connector ID
-        :param connector_name:  `str`, default `None`
-            Staging's connector name
-        :param dm_name: `int`, default `100`
-            Data Model name
-        :param dm_id: `bool`, default `True`
-            Data model ID
-        :param publish: `bool`, default `True`
-            If publish after create mapping.
-        :return: None
-        """
-
-        if connector_name:
-            _con = Connectors(self.carol)
-            connector_id = _con.get_by_name(connector_name)['mdmId']
-        else:
-            assert connector_id
-            _con = Connectors(self.carol)
-            connector_name = _con.get_by_id(connector_id)['mdmName']
-
-        if dm_name:
-            dm_id = self.get_by_name(dm_name)['mdmId']
-        else:
-            assert dm_id
-            dm_name = self.get_by_id(dm_id)['mdmName']
-
-        url = f"v1/connectors/{connector_id}/entityMappings"
-
-        payload = {"mdmMasterEntityId": dm_id,
-                   "mdmMasterEntityName": dm_name,
-                   "mdmConnectorId": connector_id,
-                   "mdmStagingType": staging_name
-                   }
-        resp = self.carol.call_api(url, data=payload)
-        if publish:
-            url = f"v1/connectors/{connector_id}/entityMappings/{resp['mdmId']}/publish"
-
-            self.carol.call_api(url, method='POST')
-
-        return resp
-
     def fetch_rejected(
             self, dm_name, backend='pandas',
             return_dask_graph=False, callback=None,
@@ -716,27 +606,6 @@ class DataModel:
 
         return d
 
-    def generate_SQL_tables(self,):
-        """Geneates SQL tables for all data models. 
-
-        The tables created will be named:
-        `dm_{datamodel_name}`. 
-
-        Returns:
-            dict: Carol's response
-        """
-
-        return self.carol.call_api(path='v1/admin/entities/templates/generateSqlTables', method='POST')
-
-    def remove_SQL_tables(self,):
-        """Removes SQL tables for all data models. 
-
-        Returns:
-            dict: Carol's response
-        """
-
-        return self.carol.call_api(path='v1/admin/entities/templates/removeSqlTables', method='POST') 
-
 
 class entIntType(object):
     ent_type = 'long'
