@@ -10,7 +10,7 @@ from .utils import async_helpers
 from .utils.miscellaneous import stream_data
 from . import _CAROL_METADATA_STAGING, _NEEDED_FOR_MERGE, _CAROL_METADATA_UNTIE_STAGING
 from .utils.miscellaneous import drop_duplicated_parquet, drop_duplicated_parquet_dask
-from .utils.deprecation_msgs import _deprecation_msgs
+from .utils.deprecation_msgs import _deprecation_msgs, deprecated
 
 _SCHEMA_TYPES_MAPPING = {
     "geopoint": str,
@@ -399,6 +399,7 @@ class Staging:
         """
         return Connectors(self.carol).get_by_name(connector_name)['mdmId']
 
+    @deprecated('2.55.2', '2.56.0', 'CDS Data reading is deprecated - Use Big Query layer to read data from Carol.')
     def fetch_parquet(self, staging_name, connector_id=None, connector_name=None, backend='pandas',
                       merge_records=True, return_dask_graph=False, columns=None, max_hits=None,
                       return_metadata=False, callback=None, cds=True, max_workers=None, file_pattern=None,
@@ -540,234 +541,3 @@ class Staging:
             d = d.drop(labels=to_drop, axis=1)
 
         return d
-
-    def export(self, staging_name, connector_id=None, connector_name=None, sync_staging=True, full_export=False,
-               delete_previous=False):
-        """
-        @DEPRECATED. This function was removed in pycarol 3.34
-
-        Export Staging from RT to CDS
-
-        This method will trigger or pause the export of the data in the staging to
-        CDS.
-
-        Args:
-            staging_name: `str`, default `None`
-                Staging name to send the data. If empty it will get from the `schema`
-            connector_id: `str`, default `None`
-                Connector name. If empty it will get from the `schema`
-            connector_name: `str`, default `None`
-                Connector name. If empty it will get from the `schema`
-            sync_staging: `bool` default `True`
-                Start export for this staging
-            full_export: `bool` default `False`
-                Full export sync for this staging
-            delete_previous: `bool` default `False`
-                Delete previous data.
-
-        Returns: `None`
-
-
-        Usage:
-        To trigger the export the first time:
-
-        .. code:: python
-
-
-            from pycarol.staging import Staging
-            from pycarol.auth.PwdAuth import PwdAuth
-            from pycarol.carol import Carol
-            login = Carol()
-            stag  = Staging(login)
-            stag.export(staging, connector_name=connector_name,sync_staging=True)
-
-            #To do a resync, that is, start the sync from the begining without delete old data
-            stag.export(staging, connector_name=connector_name,sync_staging=True, full_export=True)
-
-            #To delete the old data:
-            stag.export(staging, connector_name=connector_name,sync_staging=True, full_export=True, delete_previous=True)
-
-            #To Pause a sync:
-            stag.export(staging, connector_name=connector_name,sync_staging=False)
-
-
-        """
-        _deprecation_msgs("This function was removed from pyCarol")
-
-        return None
-
-    def export_all(self, connector_id=None, connector_name=None, sync_staging=True, full_export=False,
-                   delete_previous=False):
-        """
-
-        @DEPRECATED. This function was removed in pycarol 3.34
-
-        Export all Stagings from a connector to s3
-
-        This method will trigger or pause the export of all stagings  to
-        s3.
-
-        :param sync_staging: `bool`, default `True`
-            Sync the data model
-        :param connector_name: `str`
-            Connector name
-        :param connector_id: `str`
-            Connector id
-        :param full_export: `bool`, default `True`
-            Do a resync of the data model
-        :param delete_previous: `bool`, default `False`
-            Delete previous exported files.
-        :return: None
-
-        Usage: See `Staging.export()`
-        """
-
-        _deprecation_msgs("This function was removed from pyCarol")
-        return None
-
-    def _get_staging_export_stats(self):
-        """
-
-        @DEPRECATED. This function was removed in pycarol 3.34
-
-        Get export status for data models
-
-        :return: `dict`
-            dict with the information of which staging table is exporting its data.
-        """
-
-        _deprecation_msgs("This function was removed from pyCarol")
-        return None
-
-
-    def get_mapping_snapshot(self, connector_id, mapping_id, entity_space='PRODUCTION', reverse_mapping=False):
-
-        self.snap = {}
-        querystring = {"entitySpace": entity_space, "reverseMapping": reverse_mapping}
-
-        url = f"v1/connectors/{connector_id}/entityMappings/{mapping_id}/snapshot"
-        response = self.carol.call_api(url, method='GET', params=querystring, )
-
-        mapping_name = response.get('entityMappingName')
-        return {mapping_name: response}
-
-    def delete_mapping(self, staging_name=None, connector_id=None, connector_name=None, mapping_id=None,
-                       entity_space='PRODUCTION'):
-
-        cc = Connectors(self.carol)
-        st = cc.get_dm_mappings(all_connectors=True)
-
-        if mapping_id is None:
-            assert staging_name is not None, "staging_name should be set."
-            if (connector_id is None) and (connector_name is not None):
-                connector_id = Connectors(self.carol).get_by_name(connector_name)['mdmId']
-                entity = [i['mdmId'] for i in st
-                          if (i.get('mdmConnectorId') == connector_id) and
-                          (i.get('mdmStagingType') == staging_name)]
-                assert len(entity) == 1, f'No data model mapped for {staging_name}'
-                mapping_id = entity[0]
-
-            elif connector_id is None:
-                entity = [i for i in st if (i.get('mdmStagingType') == staging_name)]
-
-                if len(entity) > 1:
-                    raise KeyError(f'There are more than one connector for staging {staging_name}')
-                elif len(entity) < 1:
-                    raise KeyError(f'No data model mapped for {staging_name}')
-                entity = entity[0]
-                connector_id = entity['mdmConnectorId']
-                mapping_id = entity['mdmId']
-            elif connector_id:
-                entity = [i['mdmId'] for i in st
-                          if (i.get('mdmConnectorId') == connector_id) and
-                          (i.get('mdmStagingType') == staging_name)]
-
-                assert len(entity) == 1, f'No mapping for {staging_name}'
-                mapping_id = entity[0]
-
-        url_mapping = f'v1/connectors/{connector_id}/entityMappings/{mapping_id}'
-        querystring = {"entitySpace": entity_space, "reverseMapping": "false"}
-
-        self.carol.call_api(url_mapping, method='DELETE', params=querystring, )
-
-    def _check_if_exists(self, connector_id, staging_name):
-        conn = Connectors(self.carol)
-
-        try:
-            mappings = conn.get_dm_mappings(connector_id=connector_id, staging_name=staging_name)
-            return mappings
-        except Exception as e:
-            if 'Entity mapping not found' in str(e):
-                return None
-            else:
-                raise e
-
-    def mapping_from_snapshot(self, mapping_snapshot, connector_id=None, connector_name=None,
-                              publish=True, overwrite=False):
-
-        if connector_name:
-            connector_id = self._connector_by_name(connector_name)
-        else:
-            assert connector_id
-
-        staging_name = mapping_snapshot.get('stagingEntityType')
-        assert staging_name, f"Snapshot incomplete, `stagingEntityType` not in snapshot"
-
-        _mappings = self._check_if_exists(connector_id=connector_id, staging_name=staging_name)
-
-        if (_mappings is not None) and overwrite:
-            _mapping_id = [i['mdmId'] for i in _mappings]
-            assert len(_mapping_id) == 1
-            _mapping_id = _mapping_id[0]
-            method = 'PUT'
-            url_mapping = f"v1/connectors/{connector_id}/entityMappings/{_mapping_id}/snapshot"
-        else:
-            method = 'POST'
-            url_mapping = f'v1/connectors/{connector_id}/entityMappings/snapshot'
-
-        resp = self.carol.call_api(url_mapping, method=method, data=mapping_snapshot)
-        _mapping_id = resp['mdmEntityMapping']['mdmId']
-
-        if publish:
-            url = f"v1/connectors/{connector_id}/entityMappings/{_mapping_id}/publish"
-            self.carol.call_api(url, method='POST')
-
-
-    def generate_SQL_tables(self, connector_id=None, connector_name=None):
-        """ Generates SQL tables from a connector.
-
-        The tables created will be named:
-        `stg_{connector_id}_{staging_name}`. 
-
-        Args:
-            connector_id (str, optional): Connector ID. Defaults to None.
-            connector_name (str, optional): Connector name. Defaults to None.
-
-        Returns:
-            dict: Carol's response
-        
-
-        """
-        if connector_name:
-            connector_id = self._connector_by_name(connector_name)
-        elif connector_id is None:
-            raise ValueError("Either `connector_id` or `connector_name` should be set") 
-
-        params = {"connectorId": connector_id}
-        return self.carol.call_api(path='v3/staging/generateSqlTables', method='POST', params=params, )
-
-
-    def remove_SQL_tables(self, connector_id=None, connector_name=None):
-        """Remove all SQL tables from a connector
-
-        Args:
-            connector_id (str, optional): Connector ID. Defaults to None.
-            connector_name (str, optional): Connector name. Defaults to None.
-
-        Returns:
-            dict: Carol's response
-        
-
-        """
-
-        raise NotImplementedError("API not inplemented in Carol yet. Talk for support.")
\ No newline at end of file
