@@ -1,8 +1,12 @@
 """ Tests for deprecated features inside pyCarol
 
 """
+from unittest import mock
 import warnings
-import pytest
+
+import deprecation
+
+import pycarol
 
 
 def test_luigi_extension_deprecated():
